@@ -35,7 +35,7 @@ _Success_(return) BOOL LcReadContigious_Initialize(_In_ PLC_CONTEXT ctxLC);
 VOID LcReadContigious_Close(_In_ PLC_CONTEXT ctxLC);
 
 #ifdef _WIN32
-BOOL WINAPI DllMain(_In_ HINSTANCE hinstDLL, _In_ DWORD fdwReason, _In_ LPVOID lpvReserved)
+BOOL WINAPI DllMain(_In_ HINSTANCE hinstDLL, _In_ DWORD fdwReason, _In_ PVOID lpvReserved)
 {
     if(fdwReason == DLL_PROCESS_ATTACH) {
         ZeroMemory(&g_ctx, sizeof(LC_MAIN_CONTEXT));
@@ -176,7 +176,7 @@ VOID LcCreate_FetchDeviceParameter(_Inout_ PLC_CONTEXT ctxLC)
 EXPORTED_FUNCTION PLC_DEVICE_PARAMETER_ENTRY LcDeviceParameterGet(_In_ PLC_CONTEXT ctxLC, _In_ LPSTR szName)
 {
     for(DWORD i = 0; i < ctxLC->cDeviceParameter; i++) {
-        if(!strcmp(szName, ctxLC->pDeviceParameter[i].szName)) {
+        if(!_stricmp(szName, ctxLC->pDeviceParameter[i].szName)) {
             return &ctxLC->pDeviceParameter[i];
         }
     }
@@ -1123,6 +1123,9 @@ BOOL LcCommand_DoWork(_In_ PLC_CONTEXT ctxLC, _In_ QWORD fOption, _In_ DWORD cbD
         case LC_CMD_MEMMAP_GET_STRUCT:
             if(!ppbDataOut) { return FALSE; }
             return LcMemMap_GetRangesAsStruct(ctxLC, ppbDataOut, pcbDataOut);
+        case LC_CMD_MEMMAP_SET_STRUCT:
+            if(!cbDataIn || !pbDataIn) { return FALSE; }
+            return LcMemMap_SetRangesFromStruct(ctxLC, (PLC_MEMMAP_ENTRY)pbDataIn, cbDataIn / sizeof(LC_MEMMAP_ENTRY));
         case LC_CMD_MEMMAP_GET:
             if(!ppbDataOut) { return FALSE; }
             return LcMemMap_GetRangesAsText(ctxLC, ppbDataOut, pcbDataOut);
